# Global
KEYWORD_CHAR = "#"
# API Keywords
KEYWORD_ID = "#id"
KEYWORD_START = "#start"
KEYWORD_END = "#end"
# Modules
MODULE_CHAR = "@"
CORE_MODULE_PACKAGE = "pytijo.modules"
DEFAULT_MODULE_NAME = "tijo_re"
